@@ -3,5 +3,5 @@
 """Top-level package for sknlp-tf."""
 
 __author__ = """nanaya tachibana"""
-__email__ = 'nanaya100@gmail.com'
-__version__ = '0.1.0'
+__email__ = "nanaya100@gmail.com"
+__version__ = "0.3.1"
