@@ -143,7 +143,7 @@ class DeepTagger(SupervisedNLPModel):
             for pointer in raw_predictions:
                 predictions.append(
                     convert_global_pointer_to_tags(
-                        pointer.to_tensor(-1e20).numpy(),
+                        pointer.to_tensor(tf.float32.min).numpy(),
                         thresholds,
                         self.idx2class,
                         self.add_start_end_tag,
