@@ -13,6 +13,7 @@ class TextRNNTagger(DeepTagger):
         classes: list[str],
         max_sequence_length: int = 100,
         output_format: str = "global_pointer",
+        global_pointer_head_size: int = 64,
         crf_learning_rate_multiplier: float = 1.0,
         num_rnn_layers: int = 1,
         rnn_hidden_size: int = 512,
@@ -42,6 +43,7 @@ class TextRNNTagger(DeepTagger):
             classes,
             add_start_end_tag=False,
             output_format=output_format,
+            global_pointer_head_size=global_pointer_head_size,
             crf_learning_rate_multiplier=crf_learning_rate_multiplier,
             max_sequence_length=max_sequence_length,
             num_fc_layers=num_fc_layers,
