@@ -71,7 +71,7 @@ def convert_global_pointer_to_tags(
         for start, end in zip(*np.where(expit(score_matrix) >= thresholds[i])):
             start -= add_start_end_tag
             end -= add_start_end_tag
-            tags.append(Tag(start, end, label))
+            tags.append(Tag(int(start), int(end), label))
     return tags
 
 
